==> fprime-fpp-1.1.0a7.tar.gz: fprime-fpp-1.1.0a7/compiler/tools/fpp-format/src/main/scala/fpp-format.scala <==
package fpp.compiler

import fpp.compiler.analysis._
import fpp.compiler.ast._
import fpp.compiler.codegen._
import fpp.compiler.syntax._
import fpp.compiler.transform._
import fpp.compiler.util._
import scopt.OParser

object FPPFormat {

  case class Options(
    include: Boolean = false,
    files: List[File] = List()
  )

  def command(options: Options) = {
    Error.setTool(Tool(name))
    val files = options.files.reverse match {
      case Nil => List(File.StdIn)
      case list => list
    }
    val result = Result.seq(
      Result.map(files, Parser.parseFile (Parser.transUnit) (None) _),
      List(resolveIncludes (options) _, writeFpp (options) _)
    )
    result match {
      case Left(error) => {
        error.print
        System.exit(1)
      }
      case Right(_) => ()
    }
  }

  def main(args: Array[String]) = {
    val options = OParser.parse(oparser, args, Options())
    options match {
      case Some(options) => command(options)
      case None => ()
    }
  }

  def resolveIncludes(options: Options)(tul: List[Ast.TransUnit]): Result.Result[List[Ast.TransUnit]] = {
    options.include match {
      case true => for { 
        result <- ResolveSpecInclude.transformList(
          Analysis(),
          tul, 
          ResolveSpecInclude.transUnit
        )
      } yield result._2
      case false => Right(tul)
    }
  }

  def writeFpp(options: Options)(tul: List[Ast.TransUnit]): Result.Result[List[Ast.TransUnit]] = {
    val lines = tul.map(FppWriter.transUnit).flatten
    lines.map(Line.write(Line.stdout) _)
    Right(tul)
  }

  val builder = OParser.builder[Options]

  val name = "fpp-format"

  val oparser = {
    import builder._
    OParser.sequence(
      programName(name),
      head(name, Version.v),
      opt[Unit]('i', "include")
        .action((_, c) => c.copy(include = true))
        .text("resolve include specifiers"),
      help('h', "help").text("print this message and exit"),
      arg[String]("file ...")
        .unbounded()
        .optional()
        .action((f, c) => c.copy(files = File.fromString(f) :: c.files))
        .text("input files"),
    )
  }

}

==> fprime-fpp-1.3.0a2.tar.gz: fprime-fpp-1.3.0a2/compiler/tools/fpp-format/src/main/scala/fpp-format.scala <==
package fpp.compiler

import fpp.compiler.analysis._
import fpp.compiler.ast._
import fpp.compiler.codegen._
import fpp.compiler.syntax._
import fpp.compiler.transform._
import fpp.compiler.util._
import scopt.OParser

object FPPFormat {

  case class Options(
    include: Boolean = false,
    files: List[File] = List()
  )

  def command(options: Options) = {
    Error.setTool(Tool(name))
    val files = options.files.reverse match {
      case Nil => List(File.StdIn)
      case list => list
    }
    Result.seq(
      Result.map(files, Parser.parseFile (Parser.transUnit) (None) _),
      List(resolveIncludes (options) _, writeFpp (options) _)
    )
  }

  def main(args: Array[String]) =
    Tool(name).mainMethod(args, oparser, Options(), command)

  def resolveIncludes(options: Options)(tul: List[Ast.TransUnit]):
    Result.Result[List[Ast.TransUnit]] =
  {
    options.include match {
      case true => for { 
        result <- ResolveSpecInclude.transformList(
          Analysis(),
          tul, 
          ResolveSpecInclude.transUnit
        )
      } yield result._2
      case false => Right(tul)
    }
  }

  def writeFpp(options: Options)(tul: List[Ast.TransUnit]):
    Result.Result[List[Ast.TransUnit]] =
  {
    val lines = tul.map(FppWriter.transUnit).flatten
    lines.map(Line.write(Line.stdout) _)
    Right(tul)
  }

  val builder = OParser.builder[Options]

  val name = "fpp-format"

  val oparser = {
    import builder._
    OParser.sequence(
      programName(name),
      head(name, Version.v),
      opt[Unit]('i', "include")
        .action((_, c) => c.copy(include = true))
        .text("resolve include specifiers"),
      help('h', "help").text("print this message and exit"),
      arg[String]("file ...")
        .unbounded()
        .optional()
        .action((f, c) => c.copy(files = File.fromString(f) :: c.files))
        .text("input files"),
    )
  }

}
